-----------------------------------------------------------------------------
-- Module: @(#)checkpoint_last.sql    1.0     Date: 2019/09/01
-- Author: Lester Knutsen  Email: lester@advancedatatools.com
--         Advanced DataTools Corporation
-- Description: 
--      Tested with Informix 12.10 and Informix 14.10
-- Update: 1/20/2023 - Tested on Informix 14.10.FC9
-----------------------------------------------------------------------------
-- Here you want to see that the n_crit_waits, tot_crit_wait, and block_time are all normally zeros.
-- Occassionally when a blocking checkpoint is required, or during the very brief blocking time that
-- occassionally occurs during a non-blocking checkpoint (see type) there will be some blocking/waiting.
-- The times should be small fractions of a second or something is out-of-tune.
-- This is the basic output from onstat -g ckp

database sysmaster;

-- unload to checkpoint_last.uld
select first 10
	intvl,
	type,
	dbinfo( "utc_to_datetime", clock_time),   -- Clock time of the checkpoint
	crit_time, -- Fractional seconds spent in critical sections
	flush_time, -- Fractional seconds spent flushing dirty pages during the checkpoint
	cp_time, -- Duration of the checkpoint in fractional seconds
	n_dirty_buffs, -- Number of dirty buffers at the beginning of the checkpoint
	n_crit_waits, -- Number of processes that had to wait for the checkpoint
	tot_crit_wait, -- Total time all processes waited for the checkpoint - fractional seconds
	block_time -- Longest any process had to wait for the checkpoint - fractional seconds
from syscheckpoint
order by intvl desc;
