-----------------------------------------------------------------------------
-- Module: @(#)dbspace_io.sql	1.0     Date: 2019/09/01
-- Author: Lester Knutsen  Email: lester@advancedatatools.com
--         Advanced DataTools Corporation
-- Description: 
--	Tested with Informix 12.10 and Informix 14.10
-- Update: 1/20/2023 - Tested on Informix 14.10.FC9
-----------------------------------------------------------------------------
database sysmaster;

-- unload to dbspaceio.uld
select 
	-- How long has the server been running
	current current_time,
	( select DBINFO ('utc_to_datetime',sh_pfclrtime) from sysshmvals )  stats_reset_time,
	( select  (ROUND (( sh_curtime - sh_pfclrtime)/60)) from sysshmvals ) minutes_since_stats_reset,
	-- Dbspace Information
	name dbspace,
	d.pagesize ,
	count ( chknum ) num_chunks,
	sum( chksize ) size_sys_pages,
	sum( nfree ) free_pages,
	-- Estimate Size in KB using base page value
	( sum( chksize ) * ( select trunc(( sh_pagesize /1024 )) from sysshmvals )) size_kb, 
	( sum( nfree ) * ( select trunc(( sh_pagesize /1024 )) from sysshmvals )) free_kb, 
	-- Base Performance Info
	sum( pagesread ) pagereads,
	sum( pageswritten ) pagewrites,
	sum( reads ) num_reads,
	sum( writes ) num_writes,
	sum( readtime ) usecs_readtime,
	sum( writetime ) usecs_writetime,
	-- Ratio of pages per read (Read ahead)
	case
		when sum( pagesread ) = 0 then 0
		when sum( reads )= 0 then 0
		else
			( sum( pagesread ) / sum( reads )) 
	end pages_per_read,
	-- Ratio of pages per write (Write ahead)
	case
		when sum ( pageswritten ) = 0 then 0
		when sum ( writes) = 0 then 0
		else 
			( sum( pageswritten ) / sum( writes )) 
		end pages_per_writes,
	-- Ratio of page reads per minute
	case
		when sum( pagesread ) = 0 then 0
		else
			( sum( pagesread ) / (( select  (ROUND (( sh_curtime - sh_pfclrtime)/60)) from sysshmvals ))) 
	end pages_read_per_minute,
	-- Ratio of page writes per minute
	case
		when sum( pageswritten ) = 0 then 0
		else
			( sum( pageswritten ) / (( select  (ROUND (( sh_curtime - sh_pfclrtime)/60)) from sysshmvals )))
	end pages_write_per_minute,
	-- Percent of IO of Total
	round(	sum( pagesread ) / ( select sum( pagesread ) from sysmaster:syschktab ) , 2) read_percent,
	round(	sum( pageswritten ) / ( select sum( pageswritten ) from sysmaster:syschktab ) , 2) write_percent
from 	sysmaster:syschktab c, sysmaster:sysdbstab d
where     c.dbsnum = d.dbsnum
group by 1,2 ,3 ,4, 5 
order by 4 desc;



