-----------------------------------------------------------------------------
-- Module: @(#)logs_usage.sql	2.0     Date: 2019/09/01
-- Author: Lester Knutsen  Email: lester@advancedatatools.com
--         Advanced DataTools Corporation
--  Description:	Calculates how many logs and log pages used in the past 8 days.
--      Tested with Informix 12.10 and Informix 14.10
-- Update: 1/20/2023 - Tested on Informix 14.10.FC9
-----------------------------------------------------------------------------

database sysmaster;

-- unload to log_usage.uld
select	"Logs for last 7 days",
        count(*) logs_used,
        sum( size ) log_pages_used,
        dbinfo('utc_to_datetime', min( filltime) ) start_time,
        dbinfo('utc_to_datetime', max( filltime) ) end_time,
        (dbinfo('utc_to_datetime', max( filltime) ) - dbinfo('utc_to_datetime', min( filltime) )) total_time,
        (( max( filltime)) -  ( min( filltime) )) total_secs,
        ((( max( filltime)) -  ( min( filltime) )) /60 ) total_minutes,
        (((( max( filltime)) -  ( min( filltime) )) /60 ) /60 ) total_hours,
	( count(*) / (((( max( filltime)) -  ( min( filltime) )) /60 ) /60 )) logs_per_hour,
	( sum(size) / (((( max( filltime)) -  ( min( filltime) )) /60 ) /60 )) pages_per_hour
from syslogfil
where filltime > 0
and ( dbinfo('utc_to_datetime', ( filltime) ) > ( current -  7 units day ));


-- See all the logs used
-- unload to log_usage_all.uld
select 	number, 
	filltime, 
	dbinfo('utc_to_datetime', filltime ), 
	size  
from syslogfil 
where filltime > 0;

