-----------------------------------------------------------------------------
-- Module: @(#)server_performance_all.sql	1.0     Date: 2021/09/01
-- Author: Lester Knutsen  Email: lester@advancedatatools.com
--         Advanced DataTools Corporation
-- Discription:	Displays key server profile/perfomance ratios
--      Tested with Informix 12.10 and Informix 14.10
-- Update: 1/20/2023 - Tested on Informix 14.10.FC9
-----------------------------------------------------------------------------

database sysmaster;

-- unload to ratios.uld
--  Read Ahead ratio
select
	"Statics Uptime in Hours:  " metric,
        (ROUND (( sh_curtime - sh_pfclrtime)/60)/60 )  value -- hours_since_stats_reset
from sysshmvals
union all
select
	"Statics Uptime in Minutes:  " metric,
        (ROUND (( sh_curtime - sh_pfclrtime)/60))  value -- hours_since_stats_reset
from sysshmvals

union all
select
	"Statics Uptime in Seconds:  " metric,
        (ROUND (( sh_curtime - sh_pfclrtime)))  value -- hours_since_stats_reset
from sysshmvals
-- CPU Time
union all
select 
        "Total CPU Time:" metric, 
	(sum(usecs_user) + sum(usecs_sys) ) total_cpu
from sysvplst
union all
select  "Total Disk IO - Page RW" meteric,
        ( select sum ( value ) from sysprofile where name in ( "dskreads", "dskwrites"))  total_disk_IO
from sysdual

union all
select  "Total Buffer IO - Buffer RW" meteric,
        ( select sum ( value ) from sysprofile where name in ( "bufreads", "bufwrites"))  total_buff_IO
from sysdual

-- Memory
union all
select "Total Memory" metric,
        sum( seg_size ) total_size
from sysseglst

union all
select
        -- seg_class,
        case
                when seg_class = 1 then "Resident Memory"
                when seg_class = 2 then "Virtual Memory"
                when seg_class = 3 then "Message Memory"
                when seg_class = 4 then "Buffer Memory"
                else "Unknown"
        end class,
        -- count(*) number ,
        sum( seg_size ) total_size
        -- sum( seg_blkused )      total_blkused,
        -- sum( seg_blkfree )      total_blkfree
from sysseglst
group by 1

union all
-- Seqence Scans
select 	"Total Sequencial Scans:  " metric,
	value
from sysprofile
where name in ( "seqscans" )

union all
select
	"Scans per hour:          " metric,
	( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "seqscans" )
union all
-- Sort Information
select 	case
	when name  = "totalsorts"
		then "Total Sorts:"
	when name  = "memsorts"
		then "Memory Sorts:"
	when name  = "disksorts"
		then "Disk Sorts:"
	when name  = "maxsortspace"
		then "Max Sort Space:"
	else
		name
	end,
	value
from sysprofile
where name in ( "totalsorts", "memsorts", "disksorts", "maxsortspace" )
union all
select "Sorts per hour:" metric,
        ( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "totalsorts" )
union all

-- Buffer Ratios per hour
select "Buffer Reads per hour:" metric,
        ( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "bufreads" )
union all

select "Buffer Writes per hour:" metric,
        ( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "bufwrites" )
union all

-- Transaction commits per hour
select "Commits per hour:" metric,
        ( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "iscommits" )
union all

select "Buffer Waits per hour:" metric,
        ( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "buffwts" )
union all
select "Checkpoints Waits per hour:" metric,
        ( Value / ( select (ROUND ((( sh_curtime - sh_pfclrtime)/60)/60) )
                        from sysshmvals ))
from sysprofile
where name in ( "ckptwts" )
union all

-- Lock Information
select 	case
        when name  = "lockreqs"
                then "Lock Requests:"
        when name  = "lockwts"
                then "Lock Waits:"
        when name  = "deadlks"
                then "Dead Locks:"
        else
                name
        end,
	value
from sysprofile
where name in ( "lockreqs", "lockwts", "deadlks" )
union all

select
	"Lock Wait Ratio" metric,
	case when ( ( select value lockwts from sysprofile where name =  'lockwts' ) <> 0 )
        	then (( select value  lockreqs from sysprofile where name = 'lockreqs') /
        	( select value   lockwts from sysprofile where name =  'lockwts' ))
		else 0
	end case
from sysdual
union all

-- Write Types
select 	case
        when name  = "fgwrites"
                then "Foreground Writes (Very Bad):"
        when name  = "lruwrites"
                then "LRU Background Writes:"
        when name  = "chunkwrites"
                then "Chunk Writes:"
        else
                name
        end,
	value
from sysprofile
where name in ( "fgwrites", "lruwrites", "chunkwrites")
union all
select "LRU to Chunk Writes:" metric,
        (( select value from sysprofile where name = "lruwrites" ) /
        ( select value from sysprofile where name = "chunkwrites" ))
from sysdual
;
