-----------------------------------------------------------------------------
-- Module: @(#)Table_performance.sql	1.0     Date: 2023/01/01
-- Author: Lester Knutsen  Email: lester@advancedatatools.com
--         Advanced DataTools Corporation
-- Description: New Table Information Script - Unload the output to a file 
--              and the load the results into a worksheet for analysis
--	Tested with Informix 11.70 and Informix 12.10, 14.10
-- Update: 1/20/2023 - Tested on Informix 14.10.FC9
-----------------------------------------------------------------------------

database sysmaster;

-- unload to table_performance.uld
select
	systabnames.dbsname      database,
	systabnames.tabname      tabname,
	( dbinfo('dbspace', ti_partnum )) dbspace,
	systabnames.partnum,
	ti_rowsize   row_size,
	lockreqs,
	lockwts,
	deadlks,
	lktouts,
	isreads,
	iswrites,
	isrewrites,
	isdeletes,
	bufreads,
	bufwrites,
	seqscans,
	pagreads,
	pagwrites,
	( bufreads + bufwrites ) total_io,
	case
		when pagreads > 0 then
			( pagreads / bufreads ) 
			else 0
	end buff_read_percent,
	case
		when pagwrites > 0 then 
			( pagwrites / bufwrites )
			else 0
	end  buff_write_percent,
	(( ti_npdata * seqscans ) * ti_pagesize ) total_bytes_scanned 
from systabnames, systabinfo, outer sysptprof
where 	systabinfo.ti_partnum = systabnames.partnum
and	systabinfo.ti_partnum = sysptprof.partnum
and 	systabnames.dbsname not in ( "sysmaster", "sysuser", "sysutils", "sysadmin" )
and	systabnames.tabname not in ( select tabname from systables where tabid <=99 )
and 	ti_npdata > 0 -- remove partitions with no data pages
order by total_io desc;




