-----------------------------------------------------------------------------
-- Module: @(#)Table_waste_space.sql	1.0     Date: 2022/01/01
-- Author: Lester Knutsen  Email: lester@advancedatatools.com
--         Advanced DataTools Corporation
-- Description: Calculate Wasted space used by table
-----------------------------------------------------------------------------

database sysmaster;

-- unload to tablewaste.uld
select
	systabnames.dbsname      database,
	systabnames.tabname      tabname,
	( dbinfo('dbspace', ti_partnum )) dbspace,
	systabnames.partnum,
	ti_rowsize   row_size,
	ti_pagesize  page_size,
	ti_npused    	pages_used,
	ti_npdata    	pages_data,
	(ti_nptotal - ti_npused ) pages_free,
	ti_nrows 	num_rows,
	case
		when ( (ti_pagesize +4)  -28)  <  ti_rowsize   then "Row larger then pagesize"
		else "Row smaller then pagesize"
	end rowfit,
	case
		when ti_rowsize > 0 then 
			trunc ((ti_pagesize -28) / ( ti_rowsize +4)) 
		else 0
	end rows_per_page,
	case
		when ti_rowsize > 0 then 
			( trunc ((ti_pagesize -28) / ( ti_rowsize +4)) * ( ti_rowsize +4))
		else 0
	end kb_used_per_page,
	case
		when ti_rowsize > 0 then 
			((ti_pagesize -28) - ( trunc ((ti_pagesize -28) / ( ti_rowsize +4)) * ( ti_rowsize +4)))
		else 0
	end kb_waste_per_page,
	case
		when ti_rowsize > 0 then 
			(((ti_pagesize -28) - ( trunc ((ti_pagesize -28) / ( ti_rowsize +4)) * ( ti_rowsize +4)))* ti_npdata )
		else 0
	end kb_waste_per_table
from systabnames, systabinfo, outer sysptprof
where 	systabinfo.ti_partnum = systabnames.partnum
and	systabinfo.ti_partnum = sysptprof.partnum
and 	systabnames.dbsname not in ( "sysmaster", "sysuser", "sysutils", "sysadmin" )
and	systabnames.tabname not in ( select tabname from systables where tabid <=99 )
and 	ti_npdata > 0 -- remove partitions with no data pages
order by kb_waste_per_table desc;




